@@ -1,6 +1,7 @@
 package server
 
 import (
+	"context"
 	"encoding/base64"
 	"fmt"
 	"io/ioutil"
@@ -9,13 +10,15 @@ import (
 	"strings"
 	"testing"
 
+	ign "github.com/coreos/ignition/config/v2_2"
 	igntypes "github.com/coreos/ignition/config/v2_2/types"
 	yaml "github.com/ghodss/yaml"
-	"github.com/stretchr/testify/assert"
-	v1 "github.com/openshift/machine-config-operator/pkg/apis/machineconfiguration.openshift.io/v1"
+	mcfgv1 "github.com/openshift/machine-config-operator/pkg/apis/machineconfiguration.openshift.io/v1"
 	daemonconsts "github.com/openshift/machine-config-operator/pkg/daemon/constants"
 	"github.com/openshift/machine-config-operator/pkg/generated/clientset/versioned/fake"
+	"github.com/stretchr/testify/assert"
 	corev1 "k8s.io/api/core/v1"
+	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 )
 
 const (
@@ -49,23 +52,33 @@ func TestStringEncode(t *testing.T) {
 	}
 }
 
-func TestMachineConfigToIgnition(t *testing.T) {
+func TestEncapsulated(t *testing.T) {
 	mcPath := filepath.Join(testDir, "machine-configs", testConfig+".yaml")
 	mcData, err := ioutil.ReadFile(mcPath)
 	assert.Nil(t, err)
-	mc := new(v1.MachineConfig)
+	mc := new(mcfgv1.MachineConfig)
 	err = yaml.Unmarshal([]byte(mcData), mc)
 	assert.Nil(t, err)
-	assert.Equal(t, 1, len(mc.Spec.Config.Storage.Files))
-	assert.Equal(t, mc.Spec.Config.Storage.Files[0].Path, "/etc/coreos/update.conf")
+	mcIgnCfg, _, err := ign.Parse(mc.Spec.Config.Raw)
+	if err != nil {
+		t.Errorf("decoding Ignition Config failed: %s", err)
+	}
+	assert.Equal(t, 1, len(mcIgnCfg.Storage.Files))
+	assert.Equal(t, mcIgnCfg.Storage.Files[0].Path, "/etc/coreos/update.conf")
 
 	origMc := mc.DeepCopy()
-	ign := machineConfigToIgnition(mc)
-	assert.Equal(t, 1, len(origMc.Spec.Config.Storage.Files))
-	assert.Equal(t, 2, len(mc.Spec.Config.Storage.Files))
-	assert.Equal(t, 2, len(ign.Storage.Files))
-	assert.Equal(t, ign.Storage.Files[0].Path, "/etc/coreos/update.conf")
-	assert.Equal(t, ign.Storage.Files[1].Path, daemonconsts.MachineConfigEncapsulatedPath)
+	origIgnCfg, _, err := ign.Parse(origMc.Spec.Config.Raw)
+	if err != nil {
+		t.Errorf("decoding Ignition Config failed: %s", err)
+	}
+	err = appendEncapsulated(&mcIgnCfg, mc)
+	if err != nil {
+		t.Errorf("converting MachineConfig to raw Ignition config failed: %s", err)
+	}
+	assert.Equal(t, 1, len(origIgnCfg.Storage.Files))
+	assert.Equal(t, 2, len(mcIgnCfg.Storage.Files))
+	assert.Equal(t, mcIgnCfg.Storage.Files[0].Path, "/etc/coreos/update.conf")
+	assert.Equal(t, mcIgnCfg.Storage.Files[1].Path, daemonconsts.MachineConfigEncapsulatedPath)
 }
 
 // TestBootstrapServer tests the behavior of the machine config server
@@ -93,23 +106,33 @@ func TestBootstrapServer(t *testing.T) {
 		t.Fatalf("unexpected error while reading machine-config: %s, err: %v", mcPath, err)
 	}
 
-	mc := new(v1.MachineConfig)
+	mc := new(mcfgv1.MachineConfig)
 	err = yaml.Unmarshal([]byte(mcData), mc)
 	if err != nil {
 		t.Fatalf("unexpected error while unmarshaling machine-config: %s, err: %v", mcPath, err)
 	}
+	mcIgnCfg, _, err := ign.Parse(mc.Spec.Config.Raw)
+	if err != nil {
+		t.Errorf("decoding Ignition Config failed: %s", err)
+	}
 
 	// add new files, units in the expected Ignition.
 	kc, _, err := getKubeConfigContent(t)
 	if err != nil {
 		t.Fatal(err)
 	}
-	appendFileToIgnition(&mc.Spec.Config, defaultMachineKubeConfPath, string(kc))
+	err = appendFileToIgnition(&mcIgnCfg, defaultMachineKubeConfPath, string(kc))
+	if err != nil {
+		t.Fatalf("unexpected error while appending file to ignition: %v", err)
+	}
 	anno, err := getNodeAnnotation(mp.Status.Configuration.Name)
 	if err != nil {
 		t.Fatalf("unexpected error while creating annotations err: %v", err)
 	}
-	appendFileToIgnition(&mc.Spec.Config, daemonconsts.InitialNodeAnnotationsFilePath, anno)
+	err = appendFileToIgnition(&mcIgnCfg, daemonconsts.InitialNodeAnnotationsFilePath, anno)
+	if err != nil {
+		t.Fatalf("unexpected error while appending file to ignition: %v", err)
+	}
 
 	// initialize bootstrap server and get config.
 	bs := &bootstrapServer{
@@ -127,8 +150,16 @@ func TestBootstrapServer(t *testing.T) {
 	}
 
 	// assert on the output.
-	validateIgnitionFiles(t, mc.Spec.Config.Storage.Files, res.Storage.Files)
-	validateIgnitionSystemd(t, mc.Spec.Config.Systemd.Units, res.Systemd.Units)
+	ignCfg, _, err := ign.Parse(mc.Spec.Config.Raw)
+	if err != nil {
+		t.Fatal(err)
+	}
+	resCfg, _, err := ign.Parse(res.Raw)
+	if err != nil {
+		t.Fatal(err)
+	}
+	validateIgnitionFiles(t, ignCfg.Storage.Files, resCfg.Storage.Files)
+	validateIgnitionSystemd(t, ignCfg.Systemd.Units, resCfg.Systemd.Units)
 
 	// verify bootstrap cannot serve ignition to other pool than master
 	res, err = bs.GetConfig(poolRequest{
@@ -164,18 +195,18 @@ func TestClusterServer(t *testing.T) {
 	if err != nil {
 		t.Fatalf("unexpected error while reading machine-config: %s, err: %v", mcPath, err)
 	}
-	origMC := new(v1.MachineConfig)
+	origMC := new(mcfgv1.MachineConfig)
 	err = yaml.Unmarshal([]byte(mcData), origMC)
 	if err != nil {
 		t.Fatalf("unexpected error while unmarshaling machine-config: %s, err: %v", mcPath, err)
 	}
 
 	cs := fake.NewSimpleClientset()
-	_, err = cs.MachineconfigurationV1().MachineConfigPools().Create(mp)
+	_, err = cs.MachineconfigurationV1().MachineConfigPools().Create(context.TODO(), mp, metav1.CreateOptions{})
 	if err != nil {
 		t.Logf("err: %v", err)
 	}
-	_, err = cs.MachineconfigurationV1().MachineConfigs().Create(origMC)
+	_, err = cs.MachineconfigurationV1().MachineConfigs().Create(context.TODO(), origMC, metav1.CreateOptions{})
 	if err != nil {
 		t.Logf("err: %v", err)
 	}
@@ -185,22 +216,32 @@ func TestClusterServer(t *testing.T) {
 		kubeconfigFunc: func() ([]byte, []byte, error) { return getKubeConfigContent(t) },
 	}
 
-	mc := new(v1.MachineConfig)
+	mc := new(mcfgv1.MachineConfig)
 	err = yaml.Unmarshal([]byte(mcData), mc)
 	if err != nil {
 		t.Fatalf("unexpected error while unmarshaling machine-config: %s, err: %v", mcPath, err)
 	}
+	mcIgnCfg, _, err := ign.Parse(mc.Spec.Config.Raw)
+	if err != nil {
+		t.Errorf("decoding Ignition Config failed: %s", err)
+	}
 
 	kc, _, err := getKubeConfigContent(t)
 	if err != nil {
 		t.Fatal(err)
 	}
-	appendFileToIgnition(&mc.Spec.Config, defaultMachineKubeConfPath, string(kc))
+	err = appendFileToIgnition(&mcIgnCfg, defaultMachineKubeConfPath, string(kc))
+	if err != nil {
+		t.Fatalf("unexpected error while appending file to ignition: %v", err)
+	}
 	anno, err := getNodeAnnotation(mp.Status.Configuration.Name)
 	if err != nil {
 		t.Fatalf("unexpected error while creating annotations err: %v", err)
 	}
-	appendFileToIgnition(&mc.Spec.Config, daemonconsts.InitialNodeAnnotationsFilePath, anno)
+	err = appendFileToIgnition(&mcIgnCfg, daemonconsts.InitialNodeAnnotationsFilePath, anno)
+	if err != nil {
+		t.Fatalf("unexpected error while appending file to ignition: %v", err)
+	}
 
 	res, err := csc.GetConfig(poolRequest{
 		machineConfigPool: testPool,
@@ -209,16 +250,24 @@ func TestClusterServer(t *testing.T) {
 		t.Fatalf("expected err to be nil, received: %v", err)
 	}
 
-	validateIgnitionFiles(t, mc.Spec.Config.Storage.Files, res.Storage.Files)
-	validateIgnitionSystemd(t, mc.Spec.Config.Systemd.Units, res.Systemd.Units)
+	ignCfg, _, err := ign.Parse(mc.Spec.Config.Raw)
+	if err != nil {
+		t.Fatal(err)
+	}
+	resCfg, _, err := ign.Parse(res.Raw)
+	if err != nil {
+		t.Fatal(err)
+	}
+	validateIgnitionFiles(t, ignCfg.Storage.Files, resCfg.Storage.Files)
+	validateIgnitionSystemd(t, ignCfg.Systemd.Units, resCfg.Systemd.Units)
 
 	foundEncapsulated := false
-	for _, f := range res.Storage.Files {
+	for _, f := range resCfg.Storage.Files {
 		if f.Path != daemonconsts.MachineConfigEncapsulatedPath {
 			continue
 		}
 		foundEncapsulated = true
-		encapMc := new(v1.MachineConfig)
+		encapMc := new(mcfgv1.MachineConfig)
 		contents, err := getDecodedContent(f.Contents.Source)
 		assert.Nil(t, err)
 		err = yaml.Unmarshal([]byte(contents), encapMc)
@@ -286,13 +335,13 @@ func createFileMap(files []igntypes.File) map[string]igntypes.File {
 	return m
 }
 
-func getTestMachineConfigPool() (*v1.MachineConfigPool, error) {
+func getTestMachineConfigPool() (*mcfgv1.MachineConfigPool, error) {
 	mpPath := path.Join(testDir, "machine-pools", testPool+".yaml")
 	mpData, err := ioutil.ReadFile(mpPath)
 	if err != nil {
 		return nil, fmt.Errorf("unexpected error while reading machine-pool: %s, err: %v", mpPath, err)
 	}
-	mp := new(v1.MachineConfigPool)
+	mp := new(mcfgv1.MachineConfigPool)
 	err = yaml.Unmarshal(mpData, mp)
 	if err != nil {
 		return nil, fmt.Errorf("unexpected error while unmarshaling machine-pool: %s, err: %v", mpPath, err)
